@@ -29,6 +29,8 @@ class Order(Base):
     order_date = Column(DateTime, nullable=False, server_default=func.now())
     updated_date = Column(DateTime, nullable=True, server_onupdate=func.now())
     status = Column(Enum(OrderStatus), nullable=False)
+    contact_email = Column(String(30), nullable=False)
+    contact_phone = Column(String(15), nullable=False)
     shipping_name = Column(String(30), nullable=False)
     shipping_zip_code = Column(String(4), nullable=False)
     shipping_city = Column(String(25), nullable=False)
@@ -53,15 +55,19 @@ class OrderSchema(Schema):
     order_date = fields.DateTime(data_key='orderDate')
     updated_date = fields.DateTime(data_key='updatedDate')
     status = fields.String()
+    contact_email = fields.String(data_key='contactEmail')
+    contact_phone = fields.String(data_key='contactPhone')
     shipping_name = fields.String(data_key='shippingName')
     shipping_zip_code = fields.String(data_key='shippingZipCode')
     shipping_city = fields.String(data_key='shippingCity')
     shipping_address = fields.String(data_key='shippingAddress')
+    shipping_description = fields.String(data_key='shippingDescription')
     invoice_name = fields.String(data_key='invoiceName')
     invoice_zip_code = fields.String(data_key='invoiceZipCode')
     invoice_city = fields.String(data_key='invoiceCity')
     invoice_address = fields.String(data_key='invoiceAddress')
     invoice_tax_number = fields.String(data_key='invoiceTaxNumber')
+    invoice_description = fields.String(data_key='invoiceDescription')
     shipping_method = fields.Integer(data_key='shippingMethod')
     payment_method = fields.Integer(data_key='paymentMethod')
 
